@@ -9,6 +9,7 @@ import requests
 import re
 import time
 
+tmp_dir = 'tmp'
 
 def getUrlContent(url, headers={}, mode='', sleep=0):
     headers['method'] = headers.get('method', 'GET')
@@ -18,7 +19,6 @@ def getUrlContent(url, headers={}, mode='', sleep=0):
 
     with requests.get(url, headers=headers, stream=True) as r:
         if r.status_code != 200:
-            print('cached_url fetch failed', url, r.status_code)
             return 'HTTP ' + str(r.status_code)
 
         if mode == 'b':  # for binary
@@ -32,13 +32,11 @@ def getUrlContent(url, headers={}, mode='', sleep=0):
 
         return 'Not a webpage'
 
-
 def getFileName(url):
     k = re.sub(r'\W+', '', url.strip('/').split('/')[-1].split('.')[0])[:8]
     h = hashlib.sha224(url.encode('utf-8')).hexdigest()[:15 - len(k)][:7]
     return k + '_' + h
 
-
 def getFilePath(url):
     text = url
     for char in ['=', '&', ',']:
@@ -47,24 +45,27 @@ def getFilePath(url):
     ext = os.path.splitext(text)[1] or '.html'
     if len(ext) > 10:
         ext = ext[0] + ext[-9:]
-    return 'tmp/' + getFileName(url) + ext
+    return tmp_dir + '/' + getFileName(url) + ext
 
-
-def cachedContent(url, headers={}, mode='', sleep=0):
+def cachedContent(url, headers={}, mode='', sleep=0, ttl=float('inf')):
     cache = getFilePath(url)
     try:
-        with open(cache, 'r' + mode) as f:
-            return f.read()
+        if (ttl == float('inf') or 
+            os.path.getmtime(cache) > time.time() - ttl):
+            with open(cache, 'r' + mode) as f:
+                return f.read()
     except:
-        content = getUrlContent(url, headers, mode, sleep)
-        os.system('mkdir tmp > /dev/null 2>&1')
-        with open(cache, 'w' + mode) as f:
-            f.write(content)
-        return content
+        ...
+    content = getUrlContent(url, headers, mode, sleep)
+    os.system('mkdir -p %s > /dev/null 2>&1' % tmp_dir)
+    with open(cache, 'w' + mode) as f:
+        f.write(content)
+    return content
 
-
-def get(url, headers={}, force_cache=False, mode='', sleep=0):
+def get(url, headers={}, force_cache=False, mode='', sleep=0, ttl=0):
     if force_cache or 'test' in str(sys.argv):
-        return cachedContent(url, headers, mode, sleep)
+        ttl = float('inf')
+    if ttl != 0:
+        return cachedContent(url, headers, mode, sleep, ttl)
     else:
-        return getUrlContent(url, headers, mode, sleep)
+        return getUrlContent(url, headers, mode, sleep)
\ No newline at end of file
